@@ -42,6 +42,8 @@ HINSTANCE g2res_DLL;	/* Instance of the resource DLL */
 #define PI 3.14159265358979323846
 #endif /* PI */
 
+#define sgn(x) (x>0?1:x?-1:0)
+
 /* someday their might be a DLL version of g2 */
 #ifdef G2DLL
 BOOL WINAPI DllMain( HANDLE hModule, DWORD fdwreason,  LPVOID lpReserved )
@@ -238,6 +240,7 @@ int g2_win32_ClearPalette(int pid, void *pdp)
 int g2_win32_SetBackground(int pid, void *pdp, int color)
 	{
 	PDP->BkColor = color;
+	SetBkColor(PDP->hMemDC,PDP->BkColor);
 	return 0;
     }
 
@@ -298,6 +301,9 @@ int g2_win32_Line(int pid, void *pdp, int x1, int y1, int x2, int y2)
 	{
 	MoveToEx(PDP->hMemDC,x1,y1,NULL);
 	LineTo(PDP->hMemDC,x2,y2);
+	SetPixel(PDP->hMemDC,x1,y1,PDP->PenColor);
+	SetPixel(PDP->hMemDC,x2,y2,PDP->PenColor);
+	// specifically draw end points since windows does not include one endpoint
 	return 0;
     }
 
@@ -327,7 +333,7 @@ int g2_win32_PolyLine(int pid, void *pdp, int N, int *points)
 int g2_win32_Rectangle(int pid, void *pdp, int x, int y, int x2, int y2)
 	{
 	SelectObject(PDP->hMemDC,GetStockObject(NULL_BRUSH));
-	Rectangle(PDP->hMemDC,x,y,x2,y2);
+	Rectangle(PDP->hMemDC,x,y,x2+1,y2+1); // add one since windows excludes lower right point
 	return 0;
     }
 
@@ -335,7 +341,7 @@ int g2_win32_FilledRectangle(int pid, void *pdp, int x1, int y1, int x2, int y2)
 	{
 	SelectObject(PDP->hMemDC,PDP->hBrush);
 	SelectObject(PDP->hMemDC,PDP->hNullPen);
-	return Rectangle(PDP->hMemDC,x1,y1,x2,y2);
+	return Rectangle(PDP->hMemDC,x1,y1,x2+1,y2+1); // add one since windows excludes lower right point
 	SelectObject(PDP->hMemDC,PDP->hPen);
 	return 0;
 	}
@@ -387,14 +393,14 @@ int g2_win32_FilledPolygon(int pid, void *pdp, int N, int *points)
 int g2_win32_Ellipse(int pid, void *pdp, int x, int y, int r1, int r2)
 	{
 	SelectObject(PDP->hMemDC,GetStockObject(NULL_BRUSH));
-	return Ellipse(PDP->hMemDC,x-r1,y-r2,x+r1,y+r2);
+	return Ellipse(PDP->hMemDC,x-r1,y-r2,x+r1+1,y+r2+1); // add one since windows is end exclusive
     }
 
 int g2_win32_FilledEllipse(int pid, void *pdp, int x, int y, int r1, int r2)
 	{
 	SelectObject(PDP->hMemDC,PDP->hBrush);
 	SelectObject(PDP->hMemDC,PDP->hNullPen);
-	return Ellipse(PDP->hMemDC,x-r1,y-r2,x+r1,y+r2);
+	return Ellipse(PDP->hMemDC,x-r1,y-r2,x+r1+1,y+r2+1); // add one since windows is end exclusive
 	SelectObject(PDP->hMemDC,PDP->hPen);
 	return 0;
     }
@@ -427,6 +433,7 @@ int g2_win32_FilledArc(int pid, void *pdp, int x, int y, int r1, int r2, double
 int g2_win32_DrawString(int pid, void *pdp, int x, int y, const char *text)
 	{
 	SetTextColor(PDP->hMemDC,PDP->PenColor);
+	SetBkMode(PDP->hMemDC,TRANSPARENT);
 	return TextOut(PDP->hMemDC,x,y,text,strlen(text));
     }
 
@@ -445,6 +452,9 @@ int g2_win32_QueryPointer(int pid, void *pdp, int *x, int *y, unsigned int *butt
 	*x=point.x;
 	*button=0;
 
+	if (PDP->hwndThreadWindow != GetForegroundWindow())
+		return; // return if our window does not have the focus
+
 	if (GetKeyState(VK_LBUTTON)<0) 
 		*button=*button+256;
 
@@ -487,12 +497,10 @@ int InitApplication()
 
   if (g2res_DLL == NULL) 
 		printf("Warning: Could not load g2 resource DLL\n Menu and Icon are disabled\n");
-//	  	errhandler("Could not load g2res.dll",NULL);
   
 
-    wc.style = CS_HREDRAW | CS_VREDRAW; // Class style(s).
-  wc.lpfnWndProc = g2_WndProc; // Function to retrieve messages for
-							   // windows of this class.
+  wc.style = CS_HREDRAW | CS_VREDRAW; // Class style(s).
+  wc.lpfnWndProc = g2_WndProc; // Function to retrieve messages for windows of this class.
   wc.cbClsExtra = 0;	// No per-class extra data.
   wc.cbWndExtra = 0;	// No per-window extra data.
   wc.hInstance = 0;		// Application that owns the class.
@@ -504,7 +512,7 @@ int InitApplication()
 	  		errhandler("Error in LoadIcon",NULL);
 	  }
   wc.hCursor = LoadCursor(NULL, IDC_ARROW);
-  wc.hbrBackground = GetStockObject(WHITE_BRUSH);
+  wc.hbrBackground = NULL;
   wc.lpszMenuName = "G2WIN32";	
   wc.lpszClassName = "g2Window";	// Name used in call to CreateWindow.
 
@@ -582,7 +590,6 @@ int  g2_open_win32(int width, int height, const char *title, int type)
 				fprintf(stderr,"g2_win32: Thread could not be started\n");
 
 		    SetThreadPriority(PDP->hThread,THREAD_PRIORITY_ABOVE_NORMAL);
-//			printf("Waiting for thread\n");
 			//Wait till window is created by Thread
 			while( PDP->messageloop == 0)
 				Sleep(10);
