@@ -25,6 +25,7 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
+#include "g2.h"
 #include "g2_device.h"
 #include "g2_util.h"
 #include "g2_X11_P.h"
@@ -169,7 +170,7 @@ int g2_X11_init_X11X(int pid, int width, int height,
     XClassHint class_hint;
 
     if((xout->display=XOpenDisplay(NULL))==NULL) { 
-	g2_log(Error, "g2: can't open display\n");
+	g2_log(Error, "g2: can't open X11 display - check DISPLAY environment variable\n");
 	exit(-1);
     }
 
@@ -250,12 +251,14 @@ int g2_X11_init_X11X(int pid, int width, int height,
 					       w_scr.pixel, r_scr.pixel,
 					       1ul);
     }
-    
+
+    sizehints.x = xposition;
+    sizehints.y = yposition;
     sizehints.min_width = width;
     sizehints.max_width = width;
     sizehints.min_height = height;
     sizehints.max_height = height;
-    sizehints.flags = PMinSize | PMaxSize;
+    sizehints.flags = PPosition | PMinSize | PMaxSize;
     XSetStandardProperties(xout->display, xout->window,
 			   window_name, icon_name, iconPixmap,
 			   (char **)NULL, 0, &sizehints);
@@ -780,3 +783,15 @@ int g2_X11_query_pointer(int pid, void *pdp,
 
 
 
+int g2_X11_get_pd_handles(int pid, void *pdp, void *handles[G2_PD_HANDLES_SIZE])
+{
+    g2_X11_device *xout=&g2_X11_dev[pid];
+
+    handles[0]=xout->display;
+    handles[1]=&xout->window;
+    handles[2]=&xout->root;
+    handles[3]=&xout->colormap;
+    handles[4]=&xout->gc;
+    handles[5]=&xout->dest;
+    return 0;
+}
